@@ -24,16 +24,15 @@ from datetime import timedelta
 from unittest import mock
 from unittest.mock import PropertyMock, patch
 
+import pandas as pd
+import polars as pl
 import pytest
 from databricks.sql.types import Row
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowOptionalProviderFeatureException
 from airflow.models import Connection
 from airflow.providers.common.sql.hooks.handlers import fetch_all_handler
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook, create_timeout_thread
-from airflow.utils.session import provide_session
-
-pytestmark = pytest.mark.db_test
 
 TASK_ID = "databricks-sql-operator"
 DEFAULT_CONN_ID = "databricks_default"
@@ -42,15 +41,18 @@ HOST_WITH_SCHEME = "https://xx.cloud.databricks.com"
 TOKEN = "token"
 
 
-@provide_session
 @pytest.fixture(autouse=True)
-def create_connection(session):
-    conn = session.query(Connection).filter(Connection.conn_id == DEFAULT_CONN_ID).first()
-    conn.host = HOST
-    conn.login = None
-    conn.password = TOKEN
-    conn.extra = None
-    session.commit()
+def create_connection(create_connection_without_db):
+    create_connection_without_db(
+        Connection(
+            conn_id=DEFAULT_CONN_ID,
+            conn_type="databricks",
+            host=HOST,
+            login=None,
+            password=TOKEN,
+            extra=None,
+        )
+    )
 
 
 @pytest.fixture
@@ -435,3 +437,142 @@ def test_create_timeout_thread_no_timeout(
     thread = create_timeout_thread(cur=cur, execution_timeout=None)
     mock_timer.assert_not_called()
     assert thread is None
+
+
+def test_get_openlineage_default_schema_with_no_schema_set():
+    hook = DatabricksSqlHook()
+    assert hook.get_openlineage_default_schema() == "default"
+
+
+def test_get_openlineage_default_schema_with_schema_set():
+    hook = DatabricksSqlHook(schema="my-schema")
+    assert hook.get_openlineage_default_schema() == "my-schema"
+
+
+def test_get_openlineage_database_specific_lineage_with_no_query_id():
+    hook = DatabricksSqlHook()
+    hook.query_ids = []
+
+    result = hook.get_openlineage_database_specific_lineage(None)
+    assert result is None
+
+
+@mock.patch("airflow.providers.databricks.utils.openlineage.emit_openlineage_events_for_databricks_queries")
+def test_get_openlineage_database_specific_lineage_with_single_query_id(mock_emit):
+    from airflow.providers.common.compat.openlineage.facet import ExternalQueryRunFacet
+    from airflow.providers.openlineage.extractors import OperatorLineage
+
+    hook = DatabricksSqlHook()
+    hook.query_ids = ["query1"]
+    hook.get_connection = mock.MagicMock()
+    hook.get_openlineage_database_info = lambda x: mock.MagicMock(authority="auth", scheme="scheme")
+
+    ti = mock.MagicMock()
+
+    result = hook.get_openlineage_database_specific_lineage(ti)
+    mock_emit.assert_called_once_with(
+        **{
+            "hook": hook,
+            "query_ids": ["query1"],
+            "query_source_namespace": "scheme://auth",
+            "task_instance": ti,
+            "query_for_extra_metadata": True,
+        }
+    )
+    assert result == OperatorLineage(
+        run_facets={"externalQuery": ExternalQueryRunFacet(externalQueryId="query1", source="scheme://auth")}
+    )
+
+
+@mock.patch("airflow.providers.databricks.utils.openlineage.emit_openlineage_events_for_databricks_queries")
+def test_get_openlineage_database_specific_lineage_with_multiple_query_ids(mock_emit):
+    hook = DatabricksSqlHook()
+    hook.query_ids = ["query1", "query2"]
+    hook.get_connection = mock.MagicMock()
+    hook.get_openlineage_database_info = lambda x: mock.MagicMock(authority="auth", scheme="scheme")
+
+    ti = mock.MagicMock()
+
+    result = hook.get_openlineage_database_specific_lineage(ti)
+    mock_emit.assert_called_once_with(
+        **{
+            "hook": hook,
+            "query_ids": ["query1", "query2"],
+            "query_source_namespace": "scheme://auth",
+            "task_instance": ti,
+            "query_for_extra_metadata": True,
+        }
+    )
+    assert result is None
+
+
+@mock.patch("importlib.metadata.version", return_value="1.99.0")
+def test_get_openlineage_database_specific_lineage_with_old_openlineage_provider(mock_version):
+    hook = DatabricksSqlHook()
+    hook.query_ids = ["query1", "query2"]
+    hook.get_connection = mock.MagicMock()
+    hook.get_openlineage_database_info = lambda x: mock.MagicMock(authority="auth", scheme="scheme")
+
+    expected_err = (
+        "OpenLineage provider version `1.99.0` is lower than required `2.3.0`, "
+        "skipping function `emit_openlineage_events_for_databricks_queries` execution"
+    )
+    with pytest.raises(AirflowOptionalProviderFeatureException, match=expected_err):
+        hook.get_openlineage_database_specific_lineage(mock.MagicMock())
+
+
+@pytest.mark.parametrize(
+    "df_type, df_class, description",
+    [
+        pytest.param("pandas", pd.DataFrame, [(("col",))], id="pandas-dataframe"),
+        pytest.param(
+            "polars",
+            pl.DataFrame,
+            [(("col", None, None, None, None, None, None))],
+            id="polars-dataframe",
+        ),
+    ],
+)
+def test_get_df(df_type, df_class, description):
+    hook = DatabricksSqlHook()
+    statement = "SQL"
+    column = "col"
+    result_sets = [("row1",), ("row2",)]
+
+    with mock.patch(
+        "airflow.providers.databricks.hooks.databricks_sql.DatabricksSqlHook.get_conn"
+    ) as mock_get_conn:
+        if df_type == "pandas":
+            # Setup for pandas test case
+            mock_cursor = mock.MagicMock()
+            mock_cursor.description = description
+            mock_cursor.fetchall.return_value = result_sets
+            mock_get_conn.return_value.cursor.return_value = mock_cursor
+        else:
+            # Setup for polars test case
+            mock_execute = mock.MagicMock()
+            mock_execute.description = description
+            mock_execute.fetchall.return_value = result_sets
+
+            mock_cursor = mock.MagicMock()
+            mock_cursor.execute.return_value = mock_execute
+            mock_get_conn.return_value.cursor.return_value = mock_cursor
+
+        df = hook.get_df(statement, df_type=df_type)
+        mock_cursor.execute.assert_called_once_with(statement)
+
+        if df_type == "pandas":
+            mock_cursor.fetchall.assert_called_once_with()
+            assert df.columns[0] == column
+            assert df.iloc[0][0] == "row1"
+            assert df.iloc[1][0] == "row2"
+        else:
+            mock_execute.fetchall.assert_called_once_with()
+            assert df.columns[0] == column
+            assert df.row(0)[0] == result_sets[0][0]
+            assert df.row(1)[0] == result_sets[1][0]
+
+        assert isinstance(df, df_class)
+
+
+# ruff: noqa: PT028
